Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(367)

Unified Diff: ui/gfx/render_text_pango.h

Issue 26541007: ozone: Allow building for ozone without depending on pango (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: prepare-land Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/gfx/render_text_ozone.cc ('k') | ui/gfx/render_text_pango.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/gfx/render_text_pango.h
diff --git a/ui/gfx/render_text_linux.h b/ui/gfx/render_text_pango.h
similarity index 90%
rename from ui/gfx/render_text_linux.h
rename to ui/gfx/render_text_pango.h
index 296a3fe0193e2e81222ef47a895417c413ebd0a1..ba7361c4d30f8baf4536bec1c0066e3c7fe7d7b9 100644
--- a/ui/gfx/render_text_linux.h
+++ b/ui/gfx/render_text_pango.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_GFX_RENDER_TEXT_LINUX_H_
-#define UI_GFX_RENDER_TEXT_LINUX_H_
+#ifndef UI_GFX_RENDER_TEXT_PANGO_H_
+#define UI_GFX_RENDER_TEXT_PANGO_H_
#include <pango/pango.h>
#include <vector>
@@ -12,11 +12,11 @@
namespace gfx {
-// RenderTextLinux is the Linux implementation of RenderText using Pango.
-class RenderTextLinux : public RenderText {
+// RenderTextPango is the Linux implementation of RenderText using Pango.
+class RenderTextPango : public RenderText {
public:
- RenderTextLinux();
- virtual ~RenderTextLinux();
+ RenderTextPango();
+ virtual ~RenderTextPango();
// Overridden from RenderText:
virtual Size GetStringSize() OVERRIDE;
@@ -80,9 +80,9 @@ class RenderTextLinux : public RenderText {
// The text in the |layout_|.
const char* layout_text_;
- DISALLOW_COPY_AND_ASSIGN(RenderTextLinux);
+ DISALLOW_COPY_AND_ASSIGN(RenderTextPango);
};
} // namespace gfx
-#endif // UI_GFX_RENDER_TEXT_LINUX_H_
+#endif // UI_GFX_RENDER_TEXT_PANGO_H_
« no previous file with comments | « ui/gfx/render_text_ozone.cc ('k') | ui/gfx/render_text_pango.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698